/*
 * emu_tran_file.h
 *
 *  Created on: Jan 25, 2014
 *      Author: djg
 */

#ifndef EMU_TRAN_FILE_H_
#define EMU_TRAN_FILE_H_

// MFM clock and data bits are at a 10 MHz rate and the nominal rotation is
// 3600 RPM so the track contains ceil(10e6/60/32) = 5209 32 bit words
#define EMU_FILE_TRACK_DATA_BYTES (5209*4)

// Information on disk image file for emulator
typedef struct emu_file_info {
      // The size of this data in the file header
   int file_header_size_bytes;
      // Header and data size of track. All tracks are the same size
   int track_header_size_bytes;
   int track_data_size_bytes;
      // File contains num_cyl*num_head tracks
   int num_cyl;
   int num_head;
      // Rate in Hz
   int bit_rate;
} EMU_FILE_INFO;

// Information on transition data file
typedef struct tran_file_info {
   int file_header_size_bytes;
   int track_header_size_bytes;
      // File contains num_cyl*num_head tracks
   int num_cyl;
   int num_head;
      // Rate in Hz
   int sample_rate;
      // The command line used to generate the file
   char *decode_cmdline;
} TRAN_FILE_INFO;

void emu_file_write_header(char *fn, int num_cyl, int num_head);
void emu_file_read_header(char *fn, EMU_FILE_INFO *emu_file_info_out,
      int rewrite);
void emu_file_write_track_bits(uint32_t *words, int num_words, int cyl,
      int head);
int emu_file_read_track_bits(uint32_t *words, int num_bytes, int *cyl,
      int *head);
void emu_file_close(void);
int emu_file_read_track_deltas(uint16_t deltas[], int max_deltas, int *cyl,
      int *head);
void emu_file_read_cyl(int cyl, void *buf, int buf_size);
void emu_file_write_cyl(int cyl, void *buf, int buf_size);

void tran_file_write_header(char *fn, int num_cyl, int num_head, char *cmdline);
void tran_file_read_header(char *fn, TRAN_FILE_INFO *emu_file_info_out);
int tran_file_read_track_deltas(uint16_t deltas[], int max_deltas, int *cyl,
      int *head);
void tran_file_write_track_deltas(uint16_t *deltas, int num_words, int cyl, int head);
void tran_file_close(void);
#endif /* EMU_TRAN_FILE_H_ */
